==> owncloud-8.1.0p2.tgz: owncloud/core/l10n/ta_LK.js <==
OC.L10N.register(
    "core",
    {
    "Sunday" : "ஞாயிற்றுக்கிழமை",
    "Monday" : "திங்கட்கிழமை",
    "Tuesday" : "செவ்வாய்க்கிழமை",
    "Wednesday" : "புதன்கிழமை",
    "Thursday" : "வியாழக்கிழமை",
    "Friday" : "வெள்ளிக்கிழமை",
    "Saturday" : "சனிக்கிழமை",
    "January" : "தை",
    "February" : "மாசி",
    "March" : "பங்குனி",
    "April" : "சித்திரை",
    "May" : "வைகாசி",
    "June" : "ஆனி",
    "July" : "ஆடி",
    "August" : "ஆவணி",
    "September" : "புரட்டாசி",
    "October" : "ஐப்பசி",
    "November" : "கார்த்திகை",
    "December" : "மார்கழி",
    "Settings" : "அமைப்புகள்",
    "Saving..." : "சேமிக்கப்படுகிறது...",
    "No" : "இல்லை",
    "Yes" : "ஆம்",
    "Choose" : "தெரிவுசெய்க ",
    "Ok" : "சரி",
    "Cancel" : "இரத்து செய்க",
    "Share" : "பகிர்வு",
    "Error" : "வழு",
    "Error while sharing" : "பகிரும் போதான வழு",
    "Error while unsharing" : "பகிராமல் உள்ளப்போதான வழு",
    "Error while changing permissions" : "அனுமதிகள் மாறும்போதான வழு",
    "Shared with you and the group {group} by {owner}" : "உங்களுடனும் குழுவுக்கிடையிலும் {குழு} பகிரப்பட்டுள்ளது {உரிமையாளர்}",
    "Shared with you by {owner}" : "உங்களுடன் பகிரப்பட்டுள்ளது {உரிமையாளர்}",
    "Password protect" : "கடவுச்சொல்லை பாதுகாத்தல்",
    "Password" : "கடவுச்சொல்",
    "Set expiration date" : "காலாவதி தேதியை குறிப்பிடுக",
    "Expiration date" : "காலவதியாகும் திகதி",
    "group" : "குழு",
    "Resharing is not allowed" : "மீள்பகிர்வதற்கு அனுமதி இல்லை ",
    "Shared in {item} with {user}" : "{பயனாளர்} உடன் {உருப்படி} பகிரப்பட்டுள்ளது",
    "Unshare" : "பகிரப்படாதது",
    "can edit" : "தொகுக்க முடியும்",
    "access control" : "கட்டுப்பாடான அணுகல்",
    "create" : "உருவவாக்கல்",
    "delete" : "நீக்குக",
    "Password protected" : "கடவுச்சொல் பாதுகாக்கப்பட்டது",
    "Error unsetting expiration date" : "காலாவதியாகும் திகதியை குறிப்பிடாமைக்கான வழு",
    "Error setting expiration date" : "காலாவதியாகும் திகதியை குறிப்பிடுவதில் வழு",
    "Warning" : "எச்சரிக்கை",
    "The object type is not specified." : "பொருள் வகை குறிப்பிடப்படவில்லை.",
    "Delete" : "நீக்குக",
    "Add" : "சேர்க்க",
    "Use the following link to reset your password: {link}" : "உங்கள் கடவுச்சொல்லை மீளமைக்க பின்வரும் இணைப்பை பயன்படுத்தவும் : {இணைப்பு}",
    "New password" : "புதிய கடவுச்சொல்",
    "Reset password" : "மீளமைத்த கடவுச்சொல்",
    "Personal" : "தனிப்பட்ட",
    "Users" : "பயனாளர்",
    "Apps" : "செயலிகள்",
    "Admin" : "நிர்வாகம்",
    "Help" : "உதவி",
    "Access forbidden" : "அணுக தடை",
    "Create an <strong>admin account</strong>" : "<strong> நிர்வாக கணக்கொன்றை </strong> உருவாக்குக",
    "Username" : "பயனாளர் பெயர்",
    "Data folder" : "தரவு கோப்புறை",
    "Configure the database" : "தரவுத்தளத்தை தகவமைக்க",
    "Database user" : "தரவுத்தள பயனாளர்",
    "Database password" : "தரவுத்தள கடவுச்சொல்",
    "Database name" : "தரவுத்தள பெயர்",
    "Database tablespace" : "தரவுத்தள அட்டவணை",
    "Database host" : "தரவுத்தள ஓம்புனர்",
    "Finish setup" : "அமைப்பை முடிக்க",
    "Log out" : "விடுபதிகை செய்க",
    "Search" : "தேடுதல்",
    "remember" : "ஞாபகப்படுத்துக",
    "Log in" : "புகுபதிகை"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.3.tgz: owncloud/core/l10n/ta_LK.js <==
OC.L10N.register(
    "core",
    {
    "Sunday" : "ஞாயிற்றுக்கிழமை",
    "Monday" : "திங்கட்கிழமை",
    "Tuesday" : "செவ்வாய்க்கிழமை",
    "Wednesday" : "புதன்கிழமை",
    "Thursday" : "வியாழக்கிழமை",
    "Friday" : "வெள்ளிக்கிழமை",
    "Saturday" : "சனிக்கிழமை",
    "Sun." : "ஞாயிறு",
    "Mon." : "திங்கள்",
    "Tue." : "செவ்வாய்",
    "Wed." : "புதன்",
    "Thu." : "வியாழன்",
    "Fri." : "வெள்ளி",
    "Sat." : "சனி",
    "January" : "தை",
    "February" : "மாசி",
    "March" : "பங்குனி",
    "April" : "சித்திரை",
    "May" : "வைகாசி",
    "June" : "ஆனி",
    "July" : "ஆடி",
    "August" : "ஆவணி",
    "September" : "புரட்டாசி",
    "October" : "ஐப்பசி",
    "November" : "கார்த்திகை",
    "December" : "மார்கழி",
    "Jan." : "தை",
    "Feb." : "மாசி",
    "Mar." : "பங்குனி",
    "Apr." : "சித்திரை",
    "May." : "வைகாசி",
    "Jun." : "ஆனி",
    "Jul." : "ஆடி",
    "Aug." : "ஆவணி",
    "Sep." : "புரட்டாதி",
    "Oct." : "ஐப்பசி",
    "Nov." : "கார்த்திகை",
    "Dec." : "மார்கழி",
    "Settings" : "அமைப்புகள்",
    "Saving..." : "சேமிக்கப்படுகிறது...",
    "seconds ago" : "செக்கன்களுக்கு முன்",
    "No" : "இல்லை",
    "Yes" : "ஆம்",
    "Choose" : "தெரிவுசெய்க ",
    "Ok" : "சரி",
    "Cancel" : "இரத்து செய்க",
    "Error" : "வழு",
    "Error while sharing" : "பகிரும் போதான வழு",
    "Error while unsharing" : "பகிராமல் உள்ளப்போதான வழு",
    "Error setting expiration date" : "காலாவதியாகும் திகதியை குறிப்பிடுவதில் வழு",
    "Set expiration date" : "காலாவதி தேதியை குறிப்பிடுக",
    "Expiration date" : "காலவதியாகும் திகதி",
    "Resharing is not allowed" : "மீள்பகிர்வதற்கு அனுமதி இல்லை ",
    "Password protect" : "கடவுச்சொல்லை பாதுகாத்தல்",
    "Password" : "கடவுச்சொல்",
    "Shared with you and the group {group} by {owner}" : "உங்களுடனும் குழுவுக்கிடையிலும் {குழு} பகிரப்பட்டுள்ளது {உரிமையாளர்}",
    "Shared with you by {owner}" : "உங்களுடன் பகிரப்பட்டுள்ளது {உரிமையாளர்}",
    "group" : "குழு",
    "Unshare" : "பகிரப்படாதது",
    "can edit" : "தொகுக்க முடியும்",
    "create" : "உருவவாக்கல்",
    "delete" : "நீக்குக",
    "access control" : "கட்டுப்பாடான அணுகல்",
    "Share" : "பகிர்வு",
    "Warning" : "எச்சரிக்கை",
    "Delete" : "நீக்குக",
    "Rename" : "பெயர்மாற்றம்",
    "The object type is not specified." : "பொருள் வகை குறிப்பிடப்படவில்லை.",
    "Add" : "சேர்க்க",
    "Personal" : "தனிப்பட்ட",
    "Users" : "பயனாளர்",
    "Apps" : "செயலிகள்",
    "Admin" : "நிர்வாகம்",
    "Help" : "உதவி",
    "Access forbidden" : "அணுக தடை",
    "Create an <strong>admin account</strong>" : "<strong> நிர்வாக கணக்கொன்றை </strong> உருவாக்குக",
    "Username" : "பயனாளர் பெயர்",
    "Data folder" : "தரவு கோப்புறை",
    "Configure the database" : "தரவுத்தளத்தை தகவமைக்க",
    "Database user" : "தரவுத்தள பயனாளர்",
    "Database password" : "தரவுத்தள கடவுச்சொல்",
    "Database name" : "தரவுத்தள பெயர்",
    "Database tablespace" : "தரவுத்தள அட்டவணை",
    "Database host" : "தரவுத்தள ஓம்புனர்",
    "Finish setup" : "அமைப்பை முடிக்க",
    "Log out" : "விடுபதிகை செய்க",
    "Search" : "தேடுதல்",
    "Log in" : "புகுபதிகை",
    "Use the following link to reset your password: {link}" : "உங்கள் கடவுச்சொல்லை மீளமைக்க பின்வரும் இணைப்பை பயன்படுத்தவும் : {இணைப்பு}",
    "New password" : "புதிய கடவுச்சொல்",
    "Reset password" : "மீளமைத்த கடவுச்சொல்",
    "Shared with you and the group {group} by {owner}" : "உங்களுடனும் குழுவுக்கிடையிலும் {குழு} பகிரப்பட்டுள்ளது {உரிமையாளர்}"
},
"nplurals=2; plural=(n != 1);");
